..
    Copyright (C) 2025 University of Münster.

    invenio-pidstore-extra is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

Module that adds URN minting by DNB epicur service

- University of Münster <forschungsdaten@uni-muenster.de>
